**Cross River** (native name: **Oyono**)[^1] is the main
[river](https://wikipedia.org/wiki/river "wikilink") in southeastern [Nigeria](https://wikipedia.org/wiki/Nigeria "wikilink")
and gives its name to [Cross River State](https://wikipedia.org/wiki/Cross_River_State "wikilink").
It originates in [Cameroon](https://wikipedia.org/wiki/Cameroon "wikilink"), where it takes the
name of the [Manyu River](https://wikipedia.org/wiki/Manyu_River "wikilink").[^2] Although not long
by African standards its [catchment](https://wikipedia.org/wiki/drainage_basin "wikilink") has high
rainfall and it becomes very wide. Over its last to the sea it flows
through [swampy](https://wikipedia.org/wiki/swamp "wikilink") [rainforest](https://wikipedia.org/wiki/rainforest "wikilink")
with numerous [creeks](https://wikipedia.org/wiki/Stream "wikilink") and forms an [inland
delta](https://wikipedia.org/wiki/river_delta "wikilink") near its confluence with the [Calabar
River](https://wikipedia.org/wiki/Calabar_River "wikilink"),[^3] about wide and long between the
cities of [Oron](https://wikipedia.org/wiki/Oron,_Nigeria "wikilink") on the west bank and
[Calabar](https://wikipedia.org/wiki/Calabar "wikilink"), on the east bank, more than from the open
sea. The delta empties into a broad estuary[^4] which it shares with a
few smaller rivers. At its mouth in the [Atlantic
Ocean](https://wikipedia.org/wiki/Atlantic_Ocean "wikilink"), the estuary is wide. The eastern side
of the estuary is in the neighboring country of Cameroon.[^5]

The major tributary of Cross River is the river Aloma, coming from
[Benue State](https://wikipedia.org/wiki/Benue_State "wikilink") to merge with Cross River in Cross
River State. Cross River State is connected with a major highway to its
sister state [Akwa Ibom](https://wikipedia.org/wiki/Akwa_Ibom "wikilink"). The distance between
Oron and Calabar is by boat and about by road. The population of the
lower Cross River traditionally use water transport and Calabar has long
had a major [seaport](https://wikipedia.org/wiki/seaport "wikilink"), in the Calabar River about
from its confluence with the Cross River and about from the sea. The Itu
bridge on the Cross River is along Itu-Calabar highway and is reported
to be one of the landmark achievements of the
[Gowon](https://wikipedia.org/wiki/Yakubu_Gowon "wikilink") administration when it was completed in
1975.[^6]

![The Cross River, flowing through Cameroon and
Nigeria](https://wikipedia.org/wiki/Кросс-ривер.png "The Cross River, flowing through Cameroon and Nigeria")
The Cross River forms a boundary between two [tropical moist
forest](https://wikipedia.org/wiki/tropical_and_subtropical_moist_broadleaf_forests "wikilink")
[ecoregions](https://wikipedia.org/wiki/ecoregion "wikilink"): the [Cross-Niger transition
forests](https://wikipedia.org/wiki/Cross-Niger_transition_forests "wikilink"), which lie west of
the river between the Cross and [Niger](https://wikipedia.org/wiki/Niger_River "wikilink") Rivers,
and the [Cross-Sanaga-Bioko coastal
forests](https://wikipedia.org/wiki/Cross-Sanaga-Bioko_coastal_forests "wikilink"), which lie to
the east between the Cross River and the [Sanaga
River](https://wikipedia.org/wiki/Sanaga_River "wikilink") of Cameroon. The average annual rainfall
varies from 1,760 mm in the northern part of the state to 3,100 mm in
the southern part (WSSSRP II 2016).[^7] ![Dancers in Cross river state
attire](https://wikipedia.org/wiki/Cross_River_state_contingent.jpg "Dancers in Cross river state attire")

Cross River also gives its name to a [national
park](https://wikipedia.org/wiki/Cross_River_National_Park "wikilink") and a [family of
languages](https://wikipedia.org/wiki/Cross_River_languages "wikilink").[^8]

The Cross River Region is of great historical importance, being a)
within the likely homeland from which
[Bantu](https://wikipedia.org/wiki/Bantu_languages "wikilink") speaking people migrated across most
of Sub-Saharan Africa 3000–5000 years ago, b) the location of where the
[Nsibidi](https://wikipedia.org/wiki/Nsibidi "wikilink") Script was created, and c) the location of
Calabar, one of the largest centers during the [Atlantic slave
trade](https://wikipedia.org/wiki/Atlantic_slave_trade "wikilink").[^9]

## Pollution

During some months of monitoring, iron, manganese, lead, arsenic, and
chromium were identified in the water at levels hazardous for drinking;
thus, the water was polluted with these heavy metals and could not be
relied on to serve as a potable water supply for Nigerians.

## References

## External links

-   [Nigerian Tourism, Cross Rivers
    State](https://wikipedia.org/wiki/https://web.archive.org/web/20090624072650/http://www.nigeriantourism.com/cross-rivers.htm)
-   [Little genetic differentiation as assessed by uniparental markers
    in the presence of substantial language variation in peoples of the
    Cross River region of
    Nigeria](https://wikipedia.org/wiki/https://www.ncbi.nlm.nih.gov/pmc/articles/PMC2867817/)
-   [Nsibidi
    Script](https://wikipedia.org/wiki/https://web.archive.org/web/19991023140023/http://www.library.cornell.edu/africana/Writing_Systems/Nsibidi.html)

[ca:Riu Cross](https://wikipedia.org/wiki/ca:Riu_Cross "wikilink")

[ ](https://wikipedia.org/wiki/Category:Cross_River_(Nigeria) "wikilink") [Category:Rivers of
Nigeria](https://wikipedia.org/wiki/Category:Rivers_of_Nigeria "wikilink") [Category:Cross River
State](https://wikipedia.org/wiki/Category:Cross_River_State "wikilink") [Category:Rivers of
Cameroon](https://wikipedia.org/wiki/Category:Rivers_of_Cameroon "wikilink")

[^1]:

[^2]:

[^3]:

[^4]:

[^5]:
    Nigeria, Map, & Facts {{!}} Britannica
    \|url=<https://www.britannica.com/place/Cross-River-state-Nigeria>
    \|access-date=2023-09-29 \|website=www.britannica.com
    \|language=en}}

[^6]:

[^7]:

[^8]:

[^9]:
    World Civilization
    \|url=<https://courses.lumenlearning.com/suny-hccc-worldcivilization/chapter/the-bantu-migration/>
    \|access-date=2023-09-29 \|website=courses.lumenlearning.com}}